@@ -167,7 +167,7 @@ void
 commandline_undef(const struct place *p, char *str)
 {
 	if (*str == '\0') {
-		complain(NULL, "-D: macro name expected");
+		complain(NULL, "-U: macro name expected");
 		die();
 	}
 	commandline_macro_add(p, str, p, NULL);
@@ -829,6 +829,7 @@ static const struct arg_option arg_options[] = {
 	{ "MF",          commandline_setdependoutput },
 	{ "MQ",          commandline_setdependtarget_quoted },
 	{ "MT",          commandline_setdependtarget },
+	{ "debuglog",    debuglog_open },
 	{ "idirafter",   commandline_addincpath_late },
 	{ "imacros",     commandline_addfile_nooutput },
 	{ "include",     commandline_addfile_output },
@@ -1014,6 +1015,7 @@ cleanup(void)
 	commandline_files_cleanup();
 	commandline_macros_cleanup();
 	incpath_cleanup();
+	debuglog_close();
 
 	num = stringarray_num(&freestrings);
 	for (i=0; i<num; i++) {
