@@ -32,6 +32,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 
 #include "utils.h"
 #include "array.h"
@@ -52,6 +53,8 @@ static bool overall_failure;
 
 static const char *myprogname;
 
+static FILE *debuglogfile;
+
 ////////////////////////////////////////////////////////////
 // placefiles
 
@@ -283,6 +286,70 @@ complain_failed(void)
 	return overall_failure;
 }
 
+////////////////////////////////////////////////////////////
+// debug logging
+
+void
+debuglog_open(const struct place *p, /*const*/ char *file)
+{
+	assert(debuglogfile == NULL);
+	debuglogfile = fopen(file, "w");
+	if (debuglogfile == NULL) {
+		complain(p, "%s: %s", file, strerror(errno));
+		die();
+	}
+}
+
+void
+debuglog_close(void)
+{
+	if (debuglogfile != NULL) {
+		fclose(debuglogfile);
+		debuglogfile = NULL;
+	}
+}
+
+PF(2, 3) void
+debuglog(const struct place *p, const char *fmt, ...)
+{
+	va_list ap;
+
+	if (debuglogfile == NULL) {
+		return;
+	}
+
+	fprintf(debuglogfile, "%s:%u: ", place_getname(p), p->line);
+	va_start(ap, fmt);
+	vfprintf(debuglogfile, fmt, ap);
+	va_end(ap);
+	fprintf(debuglogfile, "\n");
+	fflush(debuglogfile);
+}
+
+PF(3, 4) void
+debuglog2(const struct place *p, const struct place *p2, const char *fmt, ...)
+{
+	va_list ap;
+
+	if (debuglogfile == NULL) {
+		return;
+	}
+
+	fprintf(debuglogfile, "%s:%u: ", place_getname(p), p->line);
+	if (place_samefile(p, p2)) {
+		fprintf(debuglogfile, "(block began at line %u) ",
+			p2->line);
+	} else {
+		fprintf(debuglogfile, "(block began at %s:%u)",
+			place_getname(p2), p2->line);
+	}
+	va_start(ap, fmt);
+	vfprintf(debuglogfile, fmt, ap);
+	va_end(ap);
+	fprintf(debuglogfile, "\n");
+	fflush(debuglogfile);
+}
+
 ////////////////////////////////////////////////////////////
 // module init and cleanup
 
